| addAssays | R Documentation |
Add assays
addAssays(study, assays, reset = FALSE)
study |
An OmicNavigator study created with |
assays |
The assays from the study. The input object is a list of data
frames (one per model). The row names should correspond to the featureIDs
( |
reset |
Reset the data prior to adding the new data (default:
|
Returns the original onStudy object passed to the argument
study, but modified to include the newly added data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.