| addBarcodes | R Documentation |
The app can display a barcode plot of the enrichment results for a given
annotation term. The metadata in barcodes instructs the app how to create
and label the barcode plot.
addBarcodes(study, barcodes, reset = FALSE)
study |
An OmicNavigator study created with |
barcodes |
The metadata variables that describe the barcode plot.
The input object is a list of lists (one per model). Each sublist must
contain the element
|
reset |
Reset the data prior to adding the new data (default:
|
Returns the original onStudy object passed to the argument
study, but modified to include the newly added data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.