| addEnrichments | R Documentation |
Add enrichment results
addEnrichments(study, enrichments, reset = FALSE)
study |
An OmicNavigator study created with |
enrichments |
The enrichment results from each model. The input is a
nested named list. The names of the list correspond to the model names.
Each list element should be a list of the annotation databases tested
( |
reset |
Reset the data prior to adding the new data (default:
|
Returns the original onStudy object passed to the argument
study, but modified to include the newly added data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.