| addFeatures | R Documentation |
Add feature metadata
addFeatures(study, features, reset = FALSE)
study |
An OmicNavigator study created with |
features |
The metadata variables that describe the features in the study. The input object is a list of data frames (one per model). The first column of each data frame is used as the featureID, so it must contain unique values. To share a data frame across multiple models, use the modelID "default". All columns will be coerced to character strings. |
reset |
Reset the data prior to adding the new data (default:
|
Returns the original onStudy object passed to the argument
study, but modified to include the newly added data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.