| addMetaFeaturesLinkouts | R Documentation |
You can provide additional information on the metaFeatures in your study by providing linkouts to external resources. These will be embedded directly in the metaFeatures table.
addMetaFeaturesLinkouts(study, metaFeaturesLinkouts, reset = FALSE)
study |
An OmicNavigator study created with |
metaFeaturesLinkouts |
The URL patterns that describe linkouts to external
resources (see Details below). The input object is a nested named list. The
names of the list correspond to the model names. Each element of the list
is a named list of character vectors. The names of this nested list must
correspond to the column names of the matching metaFeatures table ( |
reset |
Reset the data prior to adding the new data (default:
|
For each linkout, the URL pattern you provide will be concatenated with the
value of that column for each row. As an example, if your metaFeatures table
included a column named "ensembl" that contained the Ensembl Gene ID
for each feature, you could create a linkout to Ensembl using the following
pattern:
ensembl = "https://ensembl.org/Homo_sapiens/Gene/Summary?g="
As another example, if you had a column named "entrez" that contained
the Entrez Gene ID for each feature, you could create a linkout to Entrez
using the following pattern:
entrez = "https://www.ncbi.nlm.nih.gov/gene/"
Note that you can provide more than one linkout per column.
Returns the original onStudy object passed to the argument
study, but modified to include the newly added data
addMetaFeatures
study <- createStudy("example")
metaFeaturesLinkouts <- list(
default = list(
ensembl = c("https://ensembl.org/Homo_sapiens/Gene/Summary?g=",
"https://www.genome.ucsc.edu/cgi-bin/hgGene?hgg_gene="),
entrez = "https://www.ncbi.nlm.nih.gov/gene/"
)
)
study <- addMetaFeaturesLinkouts(study, metaFeaturesLinkouts)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.