| addReports | R Documentation |
You can include reports of the analyses you performed to generate the results.
addReports(study, reports, reset = FALSE)
study |
An OmicNavigator study created with |
reports |
The analysis report(s) that explain how the study results were generated. The input object is a list of character vectors (one per model). Each element should be either a URL or a path to a file on your computer. If it is a path to a file, this file will be included in the exported study package. To share a report across multiple models, use the modelID "default". |
reset |
Reset the data prior to adding the new data (default:
|
Returns the original onStudy object passed to the argument
study, but modified to include the newly added data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.