| addSamples | R Documentation |
Add sample metadata
addSamples(study, samples, reset = FALSE)
study |
An OmicNavigator study created with |
samples |
The metadata variables that describe the samples in the study. The input object is a named list of data frames (one per model). The first column of each data frame is used as the sampleID, so it must contain unique values. To share a data frame across multiple models, use the modelID "default". |
reset |
Reset the data prior to adding the new data (default:
|
Returns the original onStudy object passed to the argument
study, but modified to include the newly added data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.