Learn R Programming

OmicNavigator (version 1.19.0)

getEnrichmentsAnnotations: Get the annotations for the enrichments of an installed OmicNavigator study

Description

This is the API endpoint the app uses to populate the dropdown menu in the Enrichment Analysis tab with the list of available annotations for the selected model and study.

Usage

getEnrichmentsAnnotations(study, modelID, libraries = NULL)

Value

A named list. The names are the identifiers to be displayed in the dropdown menu, and each list element is a single character vector with the description to be used as a tooltip in the app. If no custom description was provided by the user, the tooltip text is simply the identifier.

Arguments

study

An OmicNavigator study. Only accepts name of installed study package.

modelID

The modelID selected by the user in the app

libraries

Character vector of library directories to search for study packages. If NULL, uses .libPaths.

Details

The annotations correspond to those used when adding the enrichments with addEnrichments. Any optional tooltips correspond to the descriptions added with addAnnotations.

See Also

getEnrichmentsStudies, getEnrichmentsModels, addEnrichments, addAnnotations