| getEnrichmentsIntersection | R Documentation |
getEnrichmentsIntersection
getEnrichmentsIntersection(
study,
modelID,
annotationID,
mustTests,
notTests,
sigValue,
operator,
type
)
study |
An OmicNavigator study. Either an object of class |
modelID |
Filter by modelID |
annotationID |
Filter by annotationID |
mustTests |
The testIDs for which a featureID (or termID for enrichment) must pass the filters |
notTests |
The testIDs for which a featureID (or termID for enrichment) must not pass the filters. In other words, if a featureID passes the filter for a testID specified in notTests, that featureID is removed from the output |
sigValue |
The numeric significance value to use as a cutoff for each column |
operator |
The comparison operators for each column, e.g. |
type |
Type of p-value: ( |
Returns a data frame with the enrichments, similar to
getEnrichmentsTable. Only rows that pass all the filters are
included.
getEnrichmentsTable
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.