Learn R Programming

OmicNavigator (version 1.19.0)

getEnrichmentsStudies: Get installed OmicNavigator studies that have enrichments

Description

This is the API endpoint the app uses to populate the dropdown menu in the Enrichment Analysis tab with the list of available studies with enrichments data.

Usage

getEnrichmentsStudies(libraries = NULL)

Value

Returns a character vector of the installed OmicNavigator study packages

Arguments

libraries

Character vector of library directories to search for study packages. If NULL, uses .libPaths.

Details

Internally, getEnrichmentsStudies calls getInstalledStudies with hasElements = "enrichments".

See Also

getInstalledStudies, getResultsStudies