getEnrichmentsUpset
getEnrichmentsUpset(
study,
modelID,
annotationID,
sigValue,
operator,
type,
tests = NULL
)No return value. This function is called for the side effect of creating an UpSet plot.
An OmicNavigator study. Either an object of class onStudy,
or the name of an installed study package.
Filter by modelID
Filter by annotationID
The numeric significance value to use as a cutoff for each column
The comparison operators for each column, e.g. "<"
Type of p-value: ("nominal" or "adjusted")
Restrict UpSet plot to only include these tests