| getFavicons | R Documentation |
To enhance the display of the linkouts in the app's tables, it can fetch the favicon URL for each website.
getFavicons(linkouts)
linkouts |
Character vector or (potentially nested) list of character vectors containing the URLs for the table linkouts. |
The URLs to the favicons for each linkout. The output returned will always be the same class and structure as the input.
getResultsLinkouts,
getEnrichmentsLinkouts
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.