Learn R Programming

OmicNavigator (version 1.19.0)

getResultsStudies: Get installed OmicNavigator studies that have results

Description

This is the API endpoint the app uses to populate the dropdown menu in the Differential Analysis tab with the list of available studies with results data.

Usage

getResultsStudies(libraries = NULL)

Value

Returns a character vector of the installed OmicNavigator study packages

Arguments

libraries

Character vector of library directories to search for study packages. If NULL, uses .libPaths.

Details

Internally, getResultsStudies calls getInstalledStudies with hasElements = "results".

See Also

getInstalledStudies, getEnrichmentsStudies