This is the API endpoint the app uses to populate the dropdown menu in the Enrichment Analysis tab with the list of available annotations for the selected model and study.
getEnrichmentsAnnotations(study, modelID, libraries = NULL)A named list. The names are the identifiers to be displayed in the dropdown menu, and each list element is a single character vector with the description to be used as a tooltip in the app. If no custom description was provided by the user, the tooltip text is simply the identifier.
An OmicNavigator study. Only accepts name of installed study package.
The modelID selected by the user in the app
Character vector of library directories to search for study
packages. If NULL, uses .libPaths.
The annotations correspond to those used when adding the enrichments with
addEnrichments. Any optional tooltips correspond to the
descriptions added with addAnnotations.
getEnrichmentsStudies,
getEnrichmentsModels,
addEnrichments,
addAnnotations