This is the API endpoint the app uses to populate the dropdown menu in the Enrichment Analysis tab with the list of available studies with enrichments data.
getEnrichmentsStudies(libraries = NULL)Returns a character vector of the installed OmicNavigator study packages
Character vector of library directories to search for study
packages. If NULL, uses .libPaths.
Internally, getEnrichmentsStudies calls
getInstalledStudies with hasElements = "enrichments".
getInstalledStudies,
getResultsStudies