This is the API endpoint the app uses to populate the dropdown menu in the Differential Analysis tab with the list of available studies with results data.
getResultsStudies(libraries = NULL)Returns a character vector of the installed OmicNavigator study packages
Character vector of library directories to search for study
packages. If NULL, uses .libPaths.
Internally, getResultsStudies calls getInstalledStudies
with hasElements = "results".
getInstalledStudies,
getEnrichmentsStudies